@@ -79,7 +79,7 @@ func runInit(sh, command string) {
 	flags := &runtime.Flags{
 		Shell:      sh,
 		ConfigPath: cfg.Source,
-		ConfigHash: cfg.Base64(),
+		ConfigHash: cfg.Hash(),
 		Strict:     strict,
 		Debug:      debug,
 		Init:       true,
@@ -90,7 +90,7 @@ func runInit(sh, command string) {
 	env := &runtime.Terminal{}
 	env.Init(flags)
 
-	cache.Init(sh, true)
+	cache.Init(sh, cache.NewSession, cache.Persist)
 
 	template.Init(env, cfg.Var, cfg.Maps)
 
@@ -114,20 +114,13 @@ func runInit(sh, command string) {
 		output = shell.Init(env, feats)
 	}
 
-	if !debug {
-		configDSC := config.DSC()
-		configDSC.Load()
-		configDSC.Add(configFlag)
-		configDSC.Save()
-
-		shellDSC := shell.DSC()
-		shellDSC.Load()
-		shellDSC.Add(&shell.Shell{
-			Command: command,
-			Name:    sh,
-		})
-		shellDSC.Save()
-	}
+	shellDSC := shell.DSC()
+	shellDSC.Load()
+	shellDSC.Add(&shell.Shell{
+		Command: command,
+		Name:    sh,
+	})
+	shellDSC.Save()
 
 	if silent {
 		return
