@@ -2,13 +2,13 @@ package config
 
 import (
 	"bytes"
+	"encoding/json"
 	"errors"
 	"fmt"
 	"hash/fnv"
 	"os"
 	"path/filepath"
-	"runtime"
-	"strconv"
+	runtimelib "runtime"
 	"strings"
 	"time"
 
@@ -18,35 +18,32 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/cli/upgrade"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
-	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 
-	json "github.com/goccy/go-json"
 	toml "github.com/pelletier/go-toml/v2"
 	yaml "gopkg.in/yaml.v3"
 )
 
-const (
-	defaultHash = "default"
-)
+// custom no config error
+var ErrNoConfig = errors.New("no config file specified")
 
-// Load returns the default configuration including possible user overrides
-func Load(configFile, sh string, migrate bool) (*Config, string) {
+func Load(configFile string, migrate bool) *Config {
 	defer log.Trace(time.Now())
 
-	configFile, err := filePath(configFile)
-	if err != nil {
-		log.Error(err)
-		warning := !errors.Is(err, ErrNoConfig)
-		return Default(warning), defaultHash
+	if configFile == "" {
+		return Default(false)
 	}
 
-	cfg, hash := readConfig(configFile)
+	configFile = resolveConfigLocation(configFile)
+
+	cfg := parseConfigFile(configFile)
 
 	// only migrate automatically when the switch isn't set
 	if !migrate && cfg.Version < Version {
 		cfg.BackupAndMigrate()
 	}
 
+	cfg.Source = configFile
+
 	if cfg.Upgrade == nil {
 		cfg.Upgrade = &upgrade.Config{
 			Source:        upgrade.CDN,
@@ -60,78 +57,29 @@ func Load(configFile, sh string, migrate bool) (*Config, string) {
 		cfg.Upgrade.Interval = cache.ONEWEEK
 	}
 
-	cfg.Source = configFile
-
-	if cfg.extended {
-		fileName := fmt.Sprintf("%s.omp.json", hash)
-		cfg.Source = filepath.Join(cache.Path(), fileName)
-		cfg.Write(JSON)
-	}
-
-	if !cfg.ShellIntegration {
-		return cfg, hash
-	}
-
-	// bash  - ok
-	// fish  - ok
-	// pwsh  - ok
-	// zsh   - ok
-	// cmd   - ok, as of v1.4.25 (chrisant996/clink#457, fixed in chrisant996/clink@8a5d7ea)
-	// nu    - built-in (and bugged) feature - nushell/nushell#5585, https://www.nushell.sh/blog/2022-08-16-nushell-0_67.html#shell-integration-fdncred-and-tyriar
-	// elv   - broken OSC sequences
-	// xonsh - broken OSC sequences
-	switch sh {
-	case shell.ELVISH, shell.XONSH, shell.NU:
-		cfg.ShellIntegration = false
-	}
-
-	return cfg, hash
+	return cfg
 }
 
-// custom no config error
-var ErrNoConfig = errors.New("no config file specified")
-
-func filePath(config string) (string, error) {
+func resolveConfigLocation(config string) string {
 	defer log.Trace(time.Now())
 
-	// if the config flag is set, we'll use that over POSH_THEME
-	// in our internal shell logic, we'll always use the POSH_THEME
-	// due to not using --config to set the configuration
-	hasConfig := len(config) > 0
-
-	if poshTheme := os.Getenv("POSH_THEME"); len(poshTheme) > 0 && !hasConfig {
-		log.Debug("config set using POSH_THEME:", poshTheme)
-		return poshTheme, nil
-	}
-
-	if !hasConfig {
-		return "", ErrNoConfig
+	if strings.HasPrefix(config, "https://") {
+		return config
 	}
 
 	if url, OK := isTheme(config); OK {
 		log.Debug("theme detected, using theme file")
-		config = url
+		return url
 	}
 
-	if strings.HasPrefix(config, "https://") {
-		filePath, err := Download(cache.Path(), config)
-		if err != nil {
-			log.Error(err)
-			return "", err
-		}
-
-		return filePath, nil
-	}
-
-	isCygwin := func() bool {
-		return runtime.GOOS == "windows" && len(os.Getenv("OSTYPE")) > 0
-	}
+	// Clean the config path so it works regardless of the OS
+	config = filepath.ToSlash(config)
 
 	// Cygwin path always needs the full path as we're on Windows but not really.
 	// Doing filepath actions will convert it to a Windows path and break the init script.
 	if isCygwin() {
 		log.Debug("cygwin detected, using full path for config")
-		return config, nil
+		return config
 	}
 
 	configFile := path.ReplaceTildePrefixWithHomeDir(config)
@@ -139,35 +87,103 @@ func filePath(config string) (string, error) {
 	abs, err := filepath.Abs(configFile)
 	if err != nil {
 		log.Error(err)
-		return filepath.Clean(configFile), nil
+		return filepath.Clean(configFile)
 	}
 
-	return abs, nil
+	return abs
 }
 
-func readConfig(configFile string) (*Config, string) {
+type hashWriter interface {
+	Write(p []byte) (n int, err error)
+}
+
+func parseConfigFile(configFile string) *Config {
+	defer log.Trace(time.Now())
+
+	configDSC := DSC()
+	configDSC.Load()
+	configDSC.Add(configFile)
+
+	defer configDSC.Save()
+
+	h := fnv.New64a()
+
+	cfg, err := readConfig(configFile, h)
+	if err != nil {
+		log.Error(err)
+		return Default(true)
+	}
+
+	parentFolder := filepath.Dir(configFile)
+
+	for cfg.Extends != "" {
+		cfg.Extends = resolveFilepath(cfg.Extends, parentFolder)
+		base, err := readConfig(cfg.Extends, h)
+		if err != nil {
+			log.Error(err)
+			break
+		}
+
+		configDSC.Add(cfg.Extends)
+
+		err = base.merge(cfg)
+		if err != nil {
+			log.Error(err)
+			break
+		}
+
+		cfg = base
+	}
+
+	cfg.hash = h.Sum64()
+
+	return cfg
+}
+
+func resolveFilepath(configFile, parentFolder string) string {
+	if strings.HasPrefix(configFile, "https://") {
+		return configFile
+	}
+
+	configFile = path.ReplaceTildePrefixWithHomeDir(configFile)
+
+	if filepath.IsAbs(configFile) {
+		return configFile
+	}
+
+	return filepath.Join(parentFolder, configFile)
+}
+
+func readConfig(configFile string, h hashWriter) (*Config, error) {
 	defer log.Trace(time.Now())
 
 	if configFile == "" {
 		log.Debug("no config file specified, using default")
-		return Default(false), defaultHash
+		return Default(false), nil
 	}
 
 	var cfg Config
 	cfg.Source = configFile
 	cfg.Format = strings.TrimPrefix(filepath.Ext(configFile), ".")
 
-	data, err := os.ReadFile(configFile)
+	getData := func(configFile string) ([]byte, error) {
+		if strings.HasPrefix(configFile, "https://") {
+			return download(configFile)
+		}
+
+		return os.ReadFile(configFile)
+	}
+
+	data, err := getData(configFile)
 	if err != nil {
-		log.Error(err)
-		return Default(true), defaultHash
+		return nil, err
 	}
 
 	switch cfg.Format {
-	case "yml", "yaml":
+	case YAML, YML:
 		cfg.Format = YAML
 		err = yaml.Unmarshal(data, &cfg)
-	case "jsonc", "json":
+	case JSONC, JSON:
 		cfg.Format = JSON
 
 		str := jsonutil.StripComments(string(data))
@@ -175,7 +191,7 @@ func readConfig(configFile string) (*Config, string) {
 
 		decoder := json.NewDecoder(bytes.NewReader(data))
 		err = decoder.Decode(&cfg)
-	case "toml", "tml":
+	case TOML, TML:
 		cfg.Format = TOML
 		err = toml.Unmarshal(data, &cfg)
 	default:
@@ -183,33 +199,20 @@ func readConfig(configFile string) (*Config, string) {
 	}
 
 	if err != nil {
-		log.Error(err)
-		return Default(true), defaultHash
+		return nil, err
 	}
 
-	// Calculate FNV-1a hash of the raw config data
-	data = append(data, []byte(configFile)...) // Include the file path in the hash to enable file modification detection
-	hasher := fnv.New64a()
-	hasher.Write(data)
-	hash := strconv.FormatUint(hasher.Sum64(), 16)
-
-	if cfg.Extends == "" {
-		return &cfg, hash
-	}
-
-	basePath, err := filePath(cfg.Extends)
-	if err != nil {
-		log.Error(err)
-		return &cfg, hash
-	}
-
-	base, baseHash := readConfig(basePath)
-	err = base.merge(&cfg)
+	_, err = h.Write(data)
 	if err != nil {
 		log.Error(err)
 	}
 
-	return base, fmt.Sprintf("%s.%s", hash, baseHash)
+	return &cfg, nil
+}
+
+// isCygwin checks if we're running in Cygwin environment
+func isCygwin() bool {
+	return runtimelib.GOOS == "windows" && len(os.Getenv("OSTYPE")) > 0
 }
 
 func isTheme(config string) (string, bool) {
