@@ -3,6 +3,7 @@ package segments
 import (
 	"net"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/http"
 )
@@ -25,7 +26,7 @@ func (i *ipAPI) Get() (*ipData, error) {
 }
 
 type IPify struct {
-	base
+	Base
 
 	api IPAPI
 	IP  string
@@ -40,14 +41,25 @@ func (i *IPify) Template() string {
 }
 
 func (i *IPify) Enabled() bool {
+	const key = "IP"
+
+	if ip, ok := cache.Get[string](cache.Device, key); ok {
+		i.IP = ip
+		return true
+	}
+
 	i.initAPI()
 
 	ip, err := i.getResult()
 	if err != nil {
 		return false
 	}
+
 	i.IP = ip
 
+	duration := i.props.GetString(properties.CacheDuration, string(cache.ONEDAY))
+	cache.Set(cache.Device, key, i.IP, cache.Duration(duration))
+
 	return true
 }
 
@@ -70,6 +82,7 @@ func (i *IPify) initAPI() {
 	}
 
 	request := &http.Request{
+		Env:         i.env,
 		HTTPTimeout: i.props.GetInt(properties.HTTPTimeout, properties.DefaultHTTPTimeout),
 	}
 
